/*--------------------------------------------------------------
// $Source: /rcs/crcs/general/os.h,v $
// Checked in by: $Author: clement $
// $Date: 1996/07/22 13:39:36 $                $Revision: 1.70 $
//--------------------------------------------------------------
//         Copyright(c) 1992, Visual Edge Software Ltd.
//         Copyright(c) 1994, International Business Machines Corp.
//
// ALL RIGHTS RESERVED. This notice is intended as a precaution
// against inadvertent publication, and shall not be deemed to
// consitute an acknowledgment that publication has occurred
// nor to imply any waiver of confidentiality. The year included
// in the notice is the year of the creation of the work.
//--------------------------------------------------------------
// DESCRIPTION:
//            This file contains global definitions & includes
//            specific of the Operating system.
// NOTE: Includes are dependent on typedefs so must be last.
//-------------------------------------------------------------*/

#ifndef OS_H
#define OS_H

#include <stdio.h>
#include <stdlib.h>

#ifdef __cplusplus
extern "C" {
#endif

/*-----------------------------------------------*/
/* Platform Independent Defines                  */
/*-----------------------------------------------*/
#define VE_MIN(x, y)	(((x) < (y)) ? (x) : (y))
#define VE_MAX(x, y)	(((x) > (y)) ? (x) : (y))

#ifndef UXPROTO
#ifdef _NO_PROTO
#define UXPROTO(x) ()
#else
#define UXPROTO(x) x
#endif
#endif

int OsDirExist UXPROTO((const char *aDirName));

/* name of the etc dir. Currently only used by   */
/* the Object Bridge.                            */
#define ETCDIR		"etc"

/*-----------------------------------------------*/
/* MSDOS Defines                                 */
/*-----------------------------------------------*/

#ifdef MSDOS
#include <io.h>
#include <float.h>
#define MAXFLOAT        FLT_MAX
#define R_OK 04
#define F_OK 00
#define VMAXPATHLEN	_MAX_PATH
#define VPutenv		_putenv

#define VSYS_WINDOWS
#define VSYS_WIN16
#define VSYS_WININTEL

#define VUSES_PLACEABLE	1
#define VUSES_FRAMES	1

#if (defined(_WINDLL) || defined(_DLL)) && !defined(VSYS_DLL)
#define VSYS_DLL
#endif

#ifndef USE_OLE2
#define USE_OLE2
#endif

#ifdef __cplusplus
#ifdef _MSC_VER
#pragma warning (disable : 4250) /* multiple inheritance */
#endif
#endif /* cplusplus */

typedef void (__cdecl * VTSigFunc)(int);
#define FILESEPSTRING   "\\"
#define FILESEPCHAR     '\\'
#define ALTFILESEPSTRING "/"
#define ALTFILESEPCHAR  '/'
#define FILEROOTCHAR    ':'
#define FILEROOTSTRING  ":"
#define FILEROOTDIRPOS  1
#define FILEBADCHARS    ""
#define NULLDEVICE      "nul"
#define NEWLINE         "\r\n"
#define VDYNLIBEXT      "dll"
#define VCURRENTDIR      "."
#define VHOMEDIR         "\\"

#define PATHSEPCHAR     ';'
#define PATHSEPSTRING   ";"
#define WILDCHARS       "?*"

#define WIDEFILESEPSTRING    L"\\"
#define WIDEFILESEPCHAR      L'\\'
#define WIDEALTFILESEPSTRING L"/"
#define WIDEALTFILESEPCHAR   L'/'
#define WIDEFILEROOTCHAR     L':'
#define WIDEFILEROOTSTRING   L":"
#define WIDEFILEBADCHARS     L""
#define WIDENULLDEVICE       L"nul"
#define WIDENEWLINE          L"\r\n"
#define VWIDEDYNLIBEXT       L"dll"
#define VWIDECURRENTDIR      L "."

#define WIDEPATHSEPCHAR      L';'
#define WIDEPATHSEPSTRING    L";"
#define WIDEWILDCHARS        L"?*"

#define INTPCALL
#define EXPORT  __export
#define VPASCAL  __pascal
#define FUNCEXPORT      __pascal __export
#define DATAEXPORT      __export

#define VOPERDECL               __export
#define VOPERDEF                __export
#define VMETHODDECL(x)          x __export
#define VMETHODDEF(x)           x __export
#define VFUNCPTR(x)             (__cdecl * x)
#define VFUNCDECL(x)            x __cdecl __export
#define VFUNCDEF(x)             x __cdecl __export
#define VDATADECL(x)            extern x __export
#define VDATADEF(x)             x __export
#ifdef __cplusplus
#define VCDATADECL(x)		extern "C" x __export
#define VCFUNCDECL(x)		extern "C" VFUNCDECL(x)
#else
#define VCDATADECL(x)		VDATADECL(x)
#define VCFUNCDECL(x)		VFUNCDECL(x)
#endif
#define VCALLBACKDECL(x)        x CALLBACK __export
#define VCALLBACKDEF(x)         x CALLBACK __export
#define VCALLBACKDATADECL(x)    x CALLBACK __export
#define VCALLBACKDATADEF(x)     x CALLBACK __export
#define VGLOBALOPERDECL(x)      x
#define VGLOBALOPERDEF(x)       x

#define VVIRTUALDECL(x)         virtual VMETHODDECL(x)
#define VVIRTUALDEF(x)          VMETHODDEF(x)
#define VVIRTOPERDECL           virtual VOPERDECL
#define VVIRTOPERDEF            VOPERDEF

#define VINLINEDECL(x)          x
#define VINLINEDEF(x)           inline x
#define VINLINEOPERDECL
#define VINLINEOPERDEF          inline
#define VSIGHDLRTYPE            void
typedef void (*VSIGHDLRPTR)(int);

#if defined(_MSC_VER)
#define VCLASS  class __far
#elif defined(__TURBOC__)
#define VCLASS  class __huge
#else
#define VCLASS  class
#endif

#define VHUGE   _huge

#ifndef _SIZE_T_DEFINED
typedef unsigned int size_t;
#define _SIZE_T_DEFINED
#endif

typedef int     OsWord;         /* native type for 16 bit signed word */

#if defined(_MSC_VER) && !defined(NOTEMPLATES)
#       define NOTEMPLATES
#endif

/*  not provided in MS runtime library */

VFUNCDECL(int) getopt(int argc, char *argv[], char *opts);
VDATADECL(int) optind;
VDATADECL(char*) optarg;

/* Define the items that are not defined
 * for Windows DLLs
 */
#ifdef _WINDLL
        #define stdin  (&_iob[0])
        #define stdout (&_iob[1])
        #define stderr (&_iob[2])
#endif /* _WINDLL */

/* low level functions common
 * to all operating systems
 */
int __cdecl EXPORT VosFprintf( FILE *, const char *, ...);
void __cdecl EXPORT VosAbort(void);
char * __cdecl EXPORT VosGets(char *);
int __cdecl EXPORT VosCancelMessage( const char * );
void __cdecl EXPORT VosExit( int );
void __cdecl EXPORT VosTerminateLoop( void );

#endif /* MSDOS */

/*-----------------------------------------------*/
/* NT (Win32) Defines                            */
/*-----------------------------------------------*/

#ifdef _WIN32
#include <io.h>
#include <float.h>

#ifndef NT
#define NT
#endif

#define MAXFLOAT        FLT_MAX
#define R_OK 04
#define F_OK 00
#define VMAXPATHLEN	_MAX_PATH
#define VPutenv		_putenv

#define VSYS_WINDOWS
#define VSYS_NT
#define VSYS_WIN32
#define VSYS_WININTEL

#define VUSES_PLACEABLE	1
#define VUSES_FRAMES	1

#if !defined(VSYS_STATIC) && !defined(VSYS_DLL)
#define VSYS_DLL
#endif

#ifndef USE_OLE2
#define USE_OLE2
#endif

#define VUSE_ODBC

#ifdef __cplusplus
#ifdef _MSC_VER
#pragma warning (disable : 4250) /* multiple inheritance */
#endif
#endif /* cplusplus */
#pragma warning(disable:4273)

typedef void (__cdecl * VTSigFunc)(int);
#define FILESEPSTRING   "\\"
#define FILESEPCHAR     '\\'
#define ALTFILESEPSTRING "/"
#define ALTFILESEPCHAR  '/'
#define FILEROOTCHAR    ':'
#define FILEROOTSTRING  ":"
#define FILEROOTDIRPOS  1
#define FILEBADCHARS    ""
#define NULLDEVICE      "nul"
#define NEWLINE         "\r\n"
#define VDYNLIBEXT      "dll"
#define VCURRENTDIR     "."
#define VHOMEDIR        "\\"

#define PATHSEPCHAR     ';'
#define PATHSEPSTRING   ";"
#define WILDCHARS       "?*"

#define WIDEFILESEPSTRING    L"\\"
#define WIDEFILESEPCHAR      L'\\'
#define WIDEALTFILESEPSTRING L"/"
#define WIDEALTFILESEPCHAR   L'/'
#define WIDEFILEROOTCHAR     L':'
#define WIDEFILEROOTSTRING   L":"
#define WIDEFILEBADCHARS     L""
#define WIDENULLDEVICE       L"nul"
#define WIDENEWLINE          L"\r\n"
#define VWIDEDYNLIBEXT       L"dll"
#define VWIDECURRENTDIR      L"."

#define WIDEPATHSEPCHAR      L';'
#define WIDEPATHSEPSTRING    L";"
#define WIDEWILDCHARS        L"?*"

#define INTPCALL
#define EXPORT
#define VPASCAL
#define FUNCEXPORT
#define DATAEXPORT

#ifndef VSYS_STATIC
#define VDLLIMPORT              __declspec(dllexport)
#define VDLLEXPORT              __declspec(dllexport)
#define VDLLDATAIMPORT          __declspec(dllimport)
#define VDLLDATAEXPORT          __declspec(dllexport)
#else
#define VDLLIMPORT
#define VDLLEXPORT
#define VDLLDATAIMPORT
#define VDLLDATAEXPORT
#endif

#define VOPERDECL               VDLLIMPORT
#define VOPERDEF                VDLLEXPORT
#define VMETHODDECL(x)          VDLLIMPORT x
#define VMETHODDEF(x)           VDLLEXPORT x
#define VFUNCPTR(x)             (* x)
#define VFUNCDECL(x)            VDLLIMPORT x __cdecl
#define VFUNCDEF(x)             VDLLEXPORT x __cdecl
#define VDATADECL(x)            extern VDLLDATAIMPORT x
#define VDATADEF(x)             VDLLDATAEXPORT x
#ifdef __cplusplus
#define VCDATADECL(x)           extern "C" VDLLDATAIMPORT x
#define VCFUNCDECL(x)		extern "C" VFUNCDECL(x)
#else
#define VCDATADECL(x)           VDATADECL(x)
#define VCFUNCDECL(x)		VFUNCDECL(x)
#endif
#define VCALLBACKDECL(x)        VDLLIMPORT x CALLBACK
#define VCALLBACKDEF(x)         VDLLEXPORT x CALLBACK
#define VCALLBACKDATADECL(x)    VDLLIMPORT x
#define VCALLBACKDATADEF(x)     VDLLEXPORT x
#define VGLOBALOPERDECL(x)      x __cdecl
#define VGLOBALOPERDEF(x)       x __cdecl

#define VVIRTUALDECL(x)         virtual VMETHODDECL(x)
#define VVIRTUALDEF(x)          VMETHODDEF(x)
#define VVIRTOPERDECL           virtual VOPERDECL
#define VVIRTOPERDEF            VOPERDEF

#define VINLINEDECL(x)          x
#define VINLINEDEF(x)           inline x
#define VINLINEOPERDECL
#define VINLINEOPERDEF          inline
#define VSIGHDLRTYPE            void __cdecl
typedef void (__cdecl *VSIGHDLRPTR)(int);

#define VCLASS  class

#define VHUGE

#ifndef _SIZE_T_DEFINED
typedef unsigned int size_t;
#define _SIZE_T_DEFINED
#endif

typedef short int     OsWord;         /* native type for 16 bit signed word */

/*  not provided in MS runtime library */
VFUNCDECL(int) getopt(int argc, char *argv[], char *opts);
VDATADECL(int) optind;
VDATADECL(char*) optarg;

/* Define the items that are not defined
 * for Windows DLLs
 */
#ifdef _WINDLL
        #define stdin  (&_iob[0])
        #define stdout (&_iob[1])
        #define stderr (&_iob[2])
#endif /* _WINDLL */

/* low level functions common
 * to all operating systems
 */
VFUNCDECL(int) VosFprintf( FILE *, const char *, ...);
VFUNCDECL(void) VosAbort(void);
VFUNCDECL(char *) VosGets(char *);
VFUNCDECL(int) VosCancelMessage( const char * );
VFUNCDECL(void) VosExit( int );
VFUNCDECL(void) VosTerminateLoop( void );


#endif /*  Win32  */

/*-----------------------------------------------*/
/* UNIX Defines                                  */
/*-----------------------------------------------*/

#if defined(unix) || defined(__unix) || defined(_AIX) || defined(UX_INTERPRETER) || defined(__unix__)
#include <unistd.h>
#include <pwd.h>
#include <values.h>

#ifndef UNIX
#define UNIX  /* to standardize the defines */
#endif

#include <sys/param.h>
#define VMAXPATHLEN	MAXPATHLEN
#define VPutenv		putenv

#define VSYS_UNIX
#define VSYS_X11
#define VSYS_MOTIF

#define VUSES_PLACEABLE	0
#define VUSES_FRAMES	0

#if defined(__GNUC__) && defined(__cplusplus)
#define VSYS_ANSICPP
#endif

#ifdef hpux
#define VSYS_NO_SIGNED
#define signed
#endif

typedef void (* VTSigFunc) UXPROTO((int));

#define FILESEPSTRING   "/"
#define FILESEPCHAR     '/'
#define ALTFILESEPSTRING "\\"
#define ALTFILESEPCHAR  '\\'
#define FILEROOTCHAR    FILESEPCHAR
#define FILEROOTSTRING  FILESEPSTRING
#define FILEROOTDIRPOS  0
#define FILEBADCHARS    "!@%^&*()=|\\`<>?\'\"[]{}; "
#define NULLDEVICE      "/dev/null"
#define NEWLINE         "\n"
#define VCURRENTDIR      "."
#define VHOMEDIR         getenv("HOME")

#if defined(_AIX)
#define VDYNLIBEXT      "a"
#elif defined(hp700v9)
#define VDYNLIBEXT      "sl"
#else
#define VDYNLIBEXT      "so"
#endif

#define PATHSEPCHAR     ':'
#define PATHSEPSTRING   ":"
#define WILDCHARS       "?*"

#if defined(hp700v9) || defined(__CLCC__)
/* Special code to work around a compiler flaw on HP.
 * See file <ob/wconst.hh> for detailed explanation.
 * Also applies to the CenterLine compiler.
 */
extern wchar_t	kVwsWideFileSepString[];
extern wchar_t	kVwsWideAltFileSepString[];
extern wchar_t	kVwsWideFileBadChars[];
extern wchar_t	kVwsWideNullDevice[];
extern wchar_t	kVwsWideNewLine[];
extern wchar_t	kVwsWideCurrentDir[];
extern wchar_t	kVwsWideVDynLibExt[];
extern wchar_t	kVwsWidePathSepString[];
extern wchar_t	kVwsWideWildChars[];
#define WIDEFILESEPSTRING    kVwsWideFileSepString
#define WIDEFILESEPCHAR      ((wchar_t)'/')
#define WIDEALTFILESEPSTRING kVwsWideAltFileSepString
#define WIDEALTFILESEPCHAR   ((wchar_t)'\\')
#define WIDEFILEROOTCHAR     WIDEFILESEPCHAR
#define WIDEFILEROOTSTRING   WIDEFILESEPSTRING
#define WIDEFILEBADCHARS     kVwsWideFileBadChars
#define WIDENULLDEVICE       kVwsWideNullDevice
#define WIDENEWLINE          kVwsWideNewLine
#define VWIDECURRENTDIR      kVwsWideCurrentDir
#define VWIDEDYNLIBEXT       kVwsWideVDynLibExt
#define WIDEPATHSEPCHAR      ((wchar_t)':')
#define WIDEPATHSEPSTRING    kVwsWidePathSepString
#define WIDEWILDCHARS        kVwsWideWildChars

#else /* all unix platforms, except HP and CenterLine environment */

#define WIDEFILESEPSTRING    L"/"
#define WIDEFILESEPCHAR      L'/'
#define WIDEALTFILESEPSTRING L"\\"
#define WIDEALTFILESEPCHAR   L'\\'
#define WIDEFILEROOTCHAR     WIDEFILESEPCHAR
#define WIDEFILEROOTSTRING   WIDEFILESEPSTRING
#define WIDEFILEBADCHARS     L"!@%^&*()=|\\`<>?\'\"[]{}; "
#define WIDENULLDEVICE       L"/dev/null"
#define WIDENEWLINE          L"\n"
#define VWIDECURRENTDIR      L"."
#if defined(_AIX)
#define VWIDEDYNLIBEXT       L"a"
#else
#define VWIDEDYNLIBEXT       L"so"
#endif /* _AIX */
#define WIDEPATHSEPCHAR      L':'
#define WIDEPATHSEPSTRING    L":"
#define WIDEWILDCHARS        L"?*"
#endif /* hp700v9 || __CLCC__ */

#define INTPCALL
#define EXPORT
#define VPASCAL
#define FUNCEXPORT
#define DATAEXPORT

#define VOPERDECL
#define VOPERDEF
#define VMETHODDECL(x)          x
#define VMETHODDEF(x)           x
#define VFUNCDECL(x)            x
#define VFUNCPTR(x)             (* x)
#define VFUNCDEF(x)             x
#define VDATADECL(x)            extern x
#define VDATADEF(x)             x
#ifdef __cplusplus
#define VCDATADECL(x)           extern "C" x
#define VCFUNCDECL(x)		extern "C" VFUNCDECL(x)
#else
#define VCDATADECL(x)           VDATADECL(x)
#define VCFUNCDECL(x)		VFUNCDECL(x)
#endif
#define VCALLBACKDECL(x)        x
#define VCALLBACKDEF(x)         x
#define VCALLBACKDATADECL(x)    x
#define VCALLBACKDATADEF(x)     x
#define VGLOBALOPERDECL(x)      x
#define VGLOBALOPERDEF(x)       x

#define VVIRTUALDECL(x)         virtual VMETHODDECL(x)
#define VVIRTUALDEF(x)          VMETHODDEF(x)
#define VVIRTOPERDECL           virtual VOPERDECL
#define VVIRTOPERDEF            VOPERDEF

#define VINLINEDECL(x)          x
#define VINLINEDEF(x)           inline x
#define VINLINEOPERDECL
#define VINLINEOPERDEF          inline
#define VSIGHDLRTYPE            void
typedef void (*VSIGHDLRPTR) UXPROTO((int));

#define VCLASS          class

#define VHUGE

typedef short OsWord;           /* native type for 16 bit signed word */

/* low level functions common
 * to all operating systems
 */
int VosCancelMessage UXPROTO((const char *));
void VosTerminateLoop UXPROTO((void));

#define VosFprintf       fprintf
#define VosAbort         abort
#define VosGets          gets
#define VosExit          exit

#endif /* unix */

/*-----------------------------------------------*/
/* OS2 Defines                                   */
/*-----------------------------------------------*/

#ifdef _OS2
#include <io.h>
#include <float.h>
#define MAXFLOAT        FLT_MAX
#define R_OK 04
#define F_OK 00
#define VMAXPATHLEN	_MAX_PATH
#define VPutenv		_putenv
#include <signal.h>
typedef _SigFunc VTSigFunc;

#define VSYS_OS2
#define VSYS_WININTEL

#define VUSES_PLACEABLE	1
#define VUSES_FRAMES	1

#if (defined(OS2DLL) || defined(_DLL)) && !defined(VSYS_DLL)
#define VSYS_DLL
#endif

#define FILESEPSTRING   "\\"
#define FILESEPCHAR     '\\'
#define ALTFILESEPSTRING "/"
#define ALTFILESEPCHAR  '/'
#define FILEROOTCHAR    ':'
#define FILEROOTSTRING  ":"
#define FILEROOTDIRPOS  1
#define FILEBADCHARS    ""
#define NULLDEVICE      "nul"
#define NEWLINE         "\r\n"
#define VDYNLIBEXT      "dll"
#define VCURRENTDIR      "."
#define VHOMEDIR         "\\"

#define PATHSEPCHAR     ';'
#define PATHSEPSTRING   ";"
#define WILDCHARS       "?*"

#define WIDEFILESEPSTRING    L"\\"
#define WIDEFILESEPCHAR      L'\\'
#define WIDEALTFILESEPSTRING L"/"
#define WIDEALTFILESEPCHAR   L'/'
#define WIDEFILEROOTCHAR     L':'
#define WIDEFILEROOTSTRING   L":"
#define WIDEFILEBADCHARS     L""
#define WIDENULLDEVICE       L"nul"
#define WIDENEWLINE          L"\r\n"
#define VWIDEDYNLIBEXT       L"dll"
#define VWIDECURRENTDIR      L"."

#define WIDEPATHSEPCHAR      L';'
#define WIDEPATHSEPSTRING    L";"
#define WIDEWILDCHARS        L"?*"

#define INTPCALL
#ifdef OS2DLL
#define EXPORT _Export
#else
#define EXPORT
#endif
#define VPASCAL
#define FUNCEXPORT   EXPORT
#define DATAEXPORT   EXPORT

#define VOPERDECL
#define VOPERDEF               EXPORT
#define VMETHODDECL(x)          x
#define VMETHODDEF(x)           x EXPORT
#define VFUNCPTR(x)             (* x)
#define VFUNCDECL(x)            x
#define VFUNCDEF(x)             x EXPORT
#define VDATADECL(x)            extern x
#define VDATADEF(x)             x EXPORT
#ifdef __cplusplus
#define VCDATADECL(x)           extern "C" x
#define VCFUNCDECL(x)		extern "C" VFUNCDECL(x)
#else
#define VCDATADECL(x)           VDATADECL(x)
#define VCFUNCDECL(x)		VFUNCDECL(x)
#endif
#define VCALLBACKDECL(x)        x
#define VCALLBACKDEF(x)         x EXPORT
#define VCALLBACKDATADECL(x)    x
#define VCALLBACKDATADEF(x)     x EXPORT
#define VGLOBALOPERDECL(x)      x
#define VGLOBALOPERDEF(x)       x

#define VVIRTUALDECL(x)         virtual VMETHODDECL(x)
#define VVIRTUALDEF(x)          VMETHODDEF(x)
#define VVIRTOPERDECL           virtual VOPERDECL
#define VVIRTOPERDEF            VOPERDEF

#define VINLINEDECL(x)          x
#define VINLINEDEF(x)           inline x
#define VINLINEOPERDECL
#define VINLINEOPERDEF          inline
#define VSIGHDLRTYPE            void
typedef void (*VSIGHDLRPTR)(int);

#define VCLASS          class

#define VHUGE

typedef short OsWord;           /* native type for 16 bit signed word */


/*  not provided in OS runtime library */

VFUNCDECL(int) getopt(int argc, char *argv[], char *opts);
VDATADECL(int) optind;
VDATADECL(char*) optarg;

/* low level functions common
 * to all operating systems
 */
int VosCancelMessage( const char * );

#define VosAbort         abort
#define VosExit          exit
VFUNCDECL(void) VosTerminateLoop( void );

VFUNCDECL(int)  VosFprintf( FILE *, const char *, ...);
VFUNCDECL(char *) VosGets(char *);
VFUNCDECL(int)  VosCancelMessage( const char * );

#endif /* os2 */


/***
 *** The following definitions are not platforms
 *** dependant.  They shall not be needed, but a
 *** compiler flaw on the HP platform forces us
 *** to define them.  The HP compiler does not
 *** implement the wide characters constant declaration
 *** syntax (ref. ANSI X3.159-1989 3.1.3.4 and 3.1.4).
 *** Until that compiler gets fixed, the following
 *** definitions are required by applications that
 *** use wide character constants.
 *** Also applies to the CenterLine compiler.
 ***/
#if defined(hp700v9) || defined(__CLCC__)
#define	WIDECOLON		((wchar_t)':')
#define	WIDEDOT			((wchar_t)'.')
#define WIDENUL			((wchar_t)'\0')
#else /* !hp700v9 && !__CLCC__ */
#define	WIDECOLON		(L':')
#define	WIDEDOT			(L'.')
#define WIDENUL			(L'\0')
#endif /* hp700v9 || __CLCC__ */

/***
 *** For Intel platforms, the printf functions family does not
 *** support parameters reordering, i.e. does not let you do the
 *** following:
 ***    printf("%2$s likes %1$s\n", "ice cream", "Fred");
 ***
 ***    output -->  Fred likes ice cream
 ***
 *** Once the platforms support it, the following declarations and macros
 *** can be removed with "crcs/general/xpg_prnt.cc" and
 *** "crcs/general/xpg_prnt.h" altogether.
 *** see fix11102
 ***/
#if defined(VSYS_WININTEL)

#if defined(VSYS_OS2)
#include <stdarg.h>
#endif

VFUNCDECL(int) VePrintf(const char *format, ...);
VFUNCDECL(int) VeFprintf(FILE *file, const char *format, ...);
VFUNCDECL(int) VeSprintf(char *outp, const char *format, ...);

VFUNCDECL(int) VeVprintf(const char *format, va_list argptr);
VFUNCDECL(int) VeVfprintf(FILE *file, const char *format, va_list argptr);
VFUNCDECL(int) VeVsprintf(char *outp, const char *format, va_list argptr);

#define printf		VePrintf
#define fprintf		VeFprintf
#define sprintf		VeSprintf

#define vprintf		VeVprintf
#define vfprintf	VeVfprintf
#define vsprintf	VeVsprintf

#endif /* VSYS_WININTEL */

#ifdef __cplusplus
}
#endif

#ifdef powerc	/* VSYS_MAC is defined in osmac.h */
#	include <osmac.h>
#endif

/*
 * here we verify all the VUSES got set
 */
#if !defined(VUSES_PLACEABLE)	/* cplace.h, VwpPlaceable, etc */
	*** intentional error ***
#elif !defined(VUSES_FRAMES)	/* 3dframes around views */
	*** intentional error ***
#endif

#endif /* OS_H */
